@@ -1,8 +1,22 @@
+// Copyright 2018 The Prometheus Authors
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
 // Scrape `information_schema.innodb_sys_tablespaces`.
 
 package collector
 
 import (
+	"context"
 	"database/sql"
 
 	"github.com/prometheus/client_golang/prometheus"
@@ -52,9 +66,14 @@ func (ScrapeInfoSchemaInnodbTablespaces) Help() string {
 	return "Collect metrics from information_schema.innodb_sys_tablespaces"
 }
 
+// Version of MySQL from which scraper is available.
+func (ScrapeInfoSchemaInnodbTablespaces) Version() float64 {
+	return 5.7
+}
+
 // Scrape collects data from database connection and sends it over channel as prometheus metric.
-func (ScrapeInfoSchemaInnodbTablespaces) Scrape(db *sql.DB, ch chan<- prometheus.Metric) error {
-	tablespacesRows, err := db.Query(innodbTablespacesQuery)
+func (ScrapeInfoSchemaInnodbTablespaces) Scrape(ctx context.Context, db *sql.DB, ch chan<- prometheus.Metric) error {
+	tablespacesRows, err := db.QueryContext(ctx, innodbTablespacesQuery)
 	if err != nil {
 		return err
 	}
@@ -99,3 +118,6 @@ func (ScrapeInfoSchemaInnodbTablespaces) Scrape(db *sql.DB, ch chan<- prometheus
 
 	return nil
 }
+
+// check interface
+var _ Scraper = ScrapeInfoSchemaInnodbTablespaces{}
