@@ -1,8 +1,22 @@
+// Copyright 2018 The Prometheus Authors
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
 // Scrape `performance_schema.events_statements_summary_by_digest`.
 
 package collector
 
 import (
+	"context"
 	"database/sql"
 	"fmt"
 
@@ -147,8 +161,13 @@ func (ScrapePerfEventsStatements) Help() string {
 	return "Collect metrics from performance_schema.events_statements_summary_by_digest"
 }
 
+// Version of MySQL from which scraper is available.
+func (ScrapePerfEventsStatements) Version() float64 {
+	return 5.6
+}
+
 // Scrape collects data from database connection and sends it over channel as prometheus metric.
-func (ScrapePerfEventsStatements) Scrape(db *sql.DB, ch chan<- prometheus.Metric) error {
+func (ScrapePerfEventsStatements) Scrape(ctx context.Context, db *sql.DB, ch chan<- prometheus.Metric) error {
 	perfQuery := fmt.Sprintf(
 		perfEventsStatementsQuery,
 		*perfEventsStatementsDigestTextLimit,
@@ -156,7 +175,7 @@ func (ScrapePerfEventsStatements) Scrape(db *sql.DB, ch chan<- prometheus.Metric
 		*perfEventsStatementsLimit,
 	)
 	// Timers here are returned in picoseconds.
-	perfSchemaEventsStatementsRows, err := db.Query(perfQuery)
+	perfSchemaEventsStatementsRows, err := db.QueryContext(ctx, perfQuery)
 	if err != nil {
 		return err
 	}
@@ -227,3 +246,6 @@ func (ScrapePerfEventsStatements) Scrape(db *sql.DB, ch chan<- prometheus.Metric
 	}
 	return nil
 }
+
+// check interface
+var _ Scraper = ScrapePerfEventsStatements{}
