@@ -1,8 +1,22 @@
+// Copyright 2018 The Prometheus Authors
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
 // Scrape `performance_schema.events_waits_summary_global_by_event_name`.
 
 package collector
 
 import (
+	"context"
 	"database/sql"
 
 	"github.com/prometheus/client_golang/prometheus"
@@ -40,10 +54,15 @@ func (ScrapePerfEventsWaits) Help() string {
 	return "Collect metrics from performance_schema.events_waits_summary_global_by_event_name"
 }
 
+// Version of MySQL from which scraper is available.
+func (ScrapePerfEventsWaits) Version() float64 {
+	return 5.5
+}
+
 // Scrape collects data from database connection and sends it over channel as prometheus metric.
-func (ScrapePerfEventsWaits) Scrape(db *sql.DB, ch chan<- prometheus.Metric) error {
+func (ScrapePerfEventsWaits) Scrape(ctx context.Context, db *sql.DB, ch chan<- prometheus.Metric) error {
 	// Timers here are returned in picoseconds.
-	perfSchemaEventsWaitsRows, err := db.Query(perfEventsWaitsQuery)
+	perfSchemaEventsWaitsRows, err := db.QueryContext(ctx, perfEventsWaitsQuery)
 	if err != nil {
 		return err
 	}
@@ -71,3 +90,6 @@ func (ScrapePerfEventsWaits) Scrape(db *sql.DB, ch chan<- prometheus.Metric) err
 	}
 	return nil
 }
+
+// check interface
+var _ Scraper = ScrapePerfEventsWaits{}
